DacsConditionalRule class
A style rule that applies only when its condition matches.
Constructors
-
DacsConditionalRule({required DacsCondition condition, required DacsStyle style, required int sourceOrder, Set<
String> ? importantFields}) - Creates a conditional style rule.
Properties
- allWidgetState → bool
-
Whether every atomic condition is a widget state condition.
no setter
- condition → DacsCondition
-
The condition required for this rule to apply.
final
-
conditions
→ List<
DacsCondition> -
The atomic conditions that make up condition.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
importantFields
→ Set<
String> ? -
Field names marked important for this rule, when applicable.
final
- isImportant → bool
-
Whether any field in this rule is marked important.
no setter
-
nonWidgetStateConditions
→ List<
DacsCondition> -
Conditions that depend on environment rather than WidgetState.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceOrder → int
-
The position of this rule in the source class string.
final
- style → DacsStyle
-
The style values contributed by this rule.
final
-
widgetStateConditions
→ List<
DacsCondition> -
Conditions that depend on WidgetState.
no setter
Methods
-
matches(
{Brightness? brightness, double? screenWidth}) → bool - Returns whether this rule matches the supplied brightness and width.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited