DacsStyleTween class
A Tween subclass that interpolates between two DacsStyle values.
Numeric fields (fontSize, opacity, borderWidth, etc.) are linearly
interpolated. Non-numeric fields (color, fontWeight, padding, etc.) use
step interpolation at t = 0.5.
- Inheritance
-
- Object
- Animatable<
DacsStyle> - Tween<
DacsStyle> - DacsStyleTween
Constructors
- DacsStyleTween({DacsStyle? begin, DacsStyle? end})
- Creates a tween between two DacsStyle values.
Properties
- begin ↔ DacsStyle?
-
The value this variable has at the beginning of the animation.
getter/setter pairinherited
- end ↔ DacsStyle?
-
The value this variable has at the end of the animation.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(
Animation< double> parent) → Animation<DacsStyle> -
Returns a new Animation that is driven by the given animation but that
takes on values determined by this object.
inherited
-
chain(
Animatable< double> parent) → Animatable<DacsStyle> -
Returns a new Animatable whose value is determined by first evaluating
the given parent and then evaluating this object at the result.
inherited
-
evaluate(
Animation< double> animation) → DacsStyle -
The current value of this object for the given Animation.
inherited
-
lerp(
double t) → DacsStyle -
Returns the value this variable has at the given animation clock value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
double t) → DacsStyle -
Returns the interpolated value for the current value of the given animation.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited